<?php
/**
* Dynamic To Top Options
*
* @package Dynamic To Top
* @subpackage Options
* @author Matt Varone
*/

add_action('admin_menu', 'dynamic_to_top_create_options_page');
add_action('admin_init', 'dynamic_to_top_register_and_build_fields');

if ( !function_exists('dynamic_to_top_create_options_page') )
{
	
	/** 
	* Create Options Page 
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_create_options_page() 
	{
		// Create Options Page
		add_options_page('Dynamic To Top Options','Dynamic To Top', 'manage_options', __FILE__, 'dynamic_to_top_options_page');
	}
}

if ( !function_exists('dynamic_to_top_register_and_build_fields') )
{
	
	/** 
	* Register and Build Fields
	*
	* Register fields and sections.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_register_and_build_fields() 
	{
		register_setting('dynamic_to_top', 'dynamic_to_top','dynamic_to_top_save_settings');

		add_settings_section('settings_section', __('Behaviour', DYNAMIC_TO_TOP_DOMAIN),'__return_true',__FILE__);
		add_settings_section('appearance_section', __('Appearance', DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_appearance_section',__FILE__);

		
		add_settings_field('speed',__('Scroll time',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_scroll_time',__FILE__,'settings_section');
		add_settings_field('distance',__('Fade-in distance',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_distance',__FILE__,'settings_section');
		add_settings_field('easing',__('Easing',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_easing',__FILE__,'settings_section');
		add_settings_field('position',__('Position',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_position',__FILE__,'settings_section');
		add_settings_field('prevent_on_mobile',__('Prevent on mobile',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_prevent_on_mobile',__FILE__,'settings_section');
			
		add_settings_field('text_version',__('Text version',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_text_version',__FILE__,'appearance_section');
		add_settings_field('text',__('Button text',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_text',__FILE__,'appearance_section');
		add_settings_field('padding_top_bottom',__('Top/bottom padding',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_padding_top_bottom',__FILE__,'appearance_section');
		add_settings_field('padding_left_right',__('Sides padding',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_padding_left_right',__FILE__,'appearance_section');
		add_settings_field('font_size',__('Font size',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_font_size',__FILE__,'appearance_section');
		add_settings_field('text_color',__('Text color',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_text_color',__FILE__,'appearance_section');
		add_settings_field('bold',__('Bold Text',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_bold',__FILE__,'appearance_section');		
		add_settings_field('text_shadow',__('Text shadow',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_text_shadow',__FILE__,'appearance_section');		
		add_settings_field('shadow_color',__('Text shadow color',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_text_shadow_color',__FILE__,'appearance_section');		
		add_settings_field('background_color',__('Background color',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_background_color',__FILE__,'appearance_section');

		add_settings_field('border_color',__('Border color',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_border_color',__FILE__,'appearance_section');
		add_settings_field('border_width',__('Border width',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_border_width',__FILE__,'appearance_section');
		add_settings_field('radius',__('Border radius',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_border_radius',__FILE__,'appearance_section');
		add_settings_field('inset',__('Inset highlighting',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_inset',__FILE__,'appearance_section');		
		add_settings_field('shadow',__('Shadow',DYNAMIC_TO_TOP_DOMAIN),'dynamic_to_top_field_shadow',__FILE__,'appearance_section');

	}
}

/*
|--------------------------------------------------------------------------
| DYNAMIC TO TOP OPTIONS PAGE
|--------------------------------------------------------------------------
*/

if ( !function_exists('dynamic_to_top_options_page') )
{
	/** 
	* Options Page
	*
	* Options page layout.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_options_page() 
	{
		
	?>
	<div class="wrap"> 
		<?php screen_icon(); ?> 
		<h2><?php echo __('Dynamic To Top Options', DYNAMIC_TO_TOP_DOMAIN); ?></h2> 
		
		<p><?php echo __('Welcome to the <strong>Dynamic To Top</strong> plugin settings. Click <a href="http://www.mattvarone.com/wordpress/dynamic-to-top-wordpress-plugin/" target="_blank">here</a> to learn more about this plugin.',DYNAMIC_TO_TOP_DOMAIN); ?></p>
		

		<form method="post" action="options.php" enctype="multipart/form-data">
			<?php settings_fields('dynamic_to_top'); ?>
			<?php do_settings_sections(__FILE__); ?>

		       <p class="submit">
		          <input name="Submit" type="submit" class="button-primary" value="<?php echo __('Save Changes', DYNAMIC_TO_TOP_DOMAIN); ?>" />
		       </p>
		
			<p><small><?php echo __('<strong>Dynamic To Top plugin</strong> brought to you by',DYNAMIC_TO_TOP_DOMAIN); ?> <a href="http://www.mattvarone.com" title="Matt Varone" target="_blank"><strong>Matt Varone</strong></a>.</small></p>
		
		</form>
	</div>
	<?php
	}

}

if ( !function_exists('dynamic_to_top_appearance_section') )
{
	function dynamic_to_top_appearance_section()
	{
		echo '<div id="dynamic-to-top-preview"><div id="dynamic-to-top-button"><span id="dtt-text"></span><span id="dtt-image"></span></div></div>';
		echo '<p class="ddt-bg-colors"><small>'.__('Preview over',DYNAMIC_TO_TOP_DOMAIN).' <a href="#" title="black">'.__('black',DYNAMIC_TO_TOP_DOMAIN).'</a>, <a href="#" title="lightgrey">'.__('grey',DYNAMIC_TO_TOP_DOMAIN).'</a> or <a href="#" title="white">'.__('white',DYNAMIC_TO_TOP_DOMAIN).'</a>.</small></p>';
	}
}

if ( !function_exists('dynamic_to_top_save_settings') )
{
	function dynamic_to_top_save_settings($options)
	{
		delete_transient('dynamic_to_top_transient_css');
		delete_transient('dynamic_to_top_transient_js');
		
		return $options;
	}
}

/*
|--------------------------------------------------------------------------
| DYNAMIC TO TOP OPTIONS PAGE ASSETS
|--------------------------------------------------------------------------
*/

if ( !function_exists('dynamic_to_top_styles') )
{
	/** 
	* Options page enqueue style.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_styles()
	{		
		if (dynamic_to_top_is_page_options()) {
			wp_enqueue_style( 'farbtastic' );
			wp_enqueue_style('dynamic-to-top-admin',DYNAMIC_TO_TOP_URL.'/css/dynamic-to-top-admin.css',array(),'1.8.13');
		}
	}
	
	add_action( 'admin_print_styles', 'dynamic_to_top_styles' );
}

if ( !function_exists('dynamic_to_top_scripts') )
{
	
	/** 
	* Options page enqueue script.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_scripts() 
	{
		if (dynamic_to_top_is_page_options())
			wp_enqueue_script('dynamic-to-top-settings',DYNAMIC_TO_TOP_URL.'/js/dynamic.to.top.settings.js',array('jquery','jquery-ui-core','farbtastic'),'1.0',true);
	}
	
	add_action( 'admin_print_scripts', 'dynamic_to_top_scripts' );
}

if ( !function_exists('dynamic_to_top_is_page_options') )
{
	
	/** 
	* Is dynamic to top page options?
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	* @return boolean 
	*
	*/
	
	function dynamic_to_top_is_page_options()
	{
		global $pagenow;
		
		if (function_exists('get_current_screen')) 
		{
			$screen = get_current_screen();
			
			if ( isset($screen->base) && $screen->base == 'settings_page_dynamic-to-top/inc/dynamic-to-top-options')
				return true;
			else
				return false;
		} 
		else 
		{
			$pages = array('options-general.php');

			if (in_array($pagenow, $pages) && isset($_GET['page']) && $_GET['page'] == 'dynamic-to-top/inc/dynamic-to-top-options.php')
			return true;
		}
		
		return false;
	}
}

/*
|--------------------------------------------------------------------------
| DYNAMIC TO TOP OPTIONS PAGE FIELDS
|--------------------------------------------------------------------------
*/

//	COLOR PICKERS ///////////////////////// 

if ( !function_exists('dynamic_to_top_field_border_color') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_border_color() 
	{
		echo dynamic_to_top_do_textfield_color('border_color','#ddd',__('Color for the button border.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_background_color') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_background_color() 
	{
		echo dynamic_to_top_do_textfield_color('background_color','#111',__('Background color for the button.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_text_color') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_text_color() 
	{
		echo dynamic_to_top_do_textfield_color('text_color','#fff',__('Button text color.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_text_shadow_color') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_text_shadow_color() 
	{
		echo dynamic_to_top_do_textfield_color('shadow_color','#333',__('Text shadow color.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_box_shadow_color') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_box_shadow_color() 
	{
		echo dynamic_to_top_do_textfield_color('box_shadow_color','#333',__('Text shadow color.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

// SELECT BOX ///////////////////////// 

if ( !function_exists('dynamic_to_top_field_easing') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function dynamic_to_top_field_easing() 
	{
		$options = array( 'Linear', 'In','Out','In Out','Bounce','Elastic');
		
		echo dynamic_to_top_do_select('easing',$options,'In',__('<a href="http://gsgd.co.uk/sandbox/jquery/easing" title="Easing type">Easing type</a> used to scroll the page up.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_position') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function dynamic_to_top_field_position() 
	{
		$options = array( 'Top Left', 'Top Right', 'Bottom Left', 'Bottom Right');
		
		echo dynamic_to_top_do_select('position',$options,'Bottom Right',__('Button position.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

// SLIDER UI ///////////////////////// 

if ( !function_exists('dynamic_to_top_field_scroll_time') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function dynamic_to_top_field_scroll_time() 
	{
		echo dynamic_to_top_do_slider('speed',1100,__('Time it takes for the page to scroll up. Less for faster. ( <span id="speed-val"></span> Milliseconds )',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_font_size') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function dynamic_to_top_field_font_size() 
	{
		echo dynamic_to_top_do_slider('font_size',1,__('Button text size. ( <span id="font-size-val"></span> Em/s )',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_padding_top_bottom') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function dynamic_to_top_field_padding_top_bottom() 
	{
		echo dynamic_to_top_do_slider('padding_top_bottom',21,__('Spacing on Top and Bottom. ( <span id="padding-top-bottom-val"></span>px )',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_padding_left_right') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function dynamic_to_top_field_padding_left_right() 
	{
		echo dynamic_to_top_do_slider('padding_left_right',19,__('Spacing on Left and Right. ( <span id="padding-left-right-val"></span>px )',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_border_width') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function dynamic_to_top_field_border_width() 
	{
		echo dynamic_to_top_do_slider('border_width','1',__('Button border width',DYNAMIC_TO_TOP_DOMAIN).' <span id="border-val"></span>px.');
	}
}

if ( !function_exists('dynamic_to_top_field_border_radius') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function dynamic_to_top_field_border_radius() 
	{
		echo dynamic_to_top_do_slider('radius','9',__('Button border radius',DYNAMIC_TO_TOP_DOMAIN).' <span id="radius-val"></span>px.');
	}
}

// TEXTFIELDS ///////////////////////// 

if ( !function_exists('dynamic_to_top_field_distance') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function dynamic_to_top_field_distance() 
	{
		echo dynamic_to_top_do_textfield('distance',300,__('Distance from top to show the button. ( Pixels )',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_text') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_text() 
	{
		echo dynamic_to_top_do_textfield('text',__('To Top',DYNAMIC_TO_TOP_DOMAIN),__('Text displayed on the button.',DYNAMIC_TO_TOP_DOMAIN),'regular-text');
	}
}

// CHECKBOXES ///////////////////////// 

if ( !function_exists('dynamic_to_top_field_prevent_on_mobile') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_prevent_on_mobile() 
	{
		echo dynamic_to_top_do_checkbox('prevent_on_mobile',__('Yes',DYNAMIC_TO_TOP_DOMAIN),'yes',false,__('Disable the button on mobile browsers.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_text_version') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_text_version() 
	{
		echo dynamic_to_top_do_checkbox('text_version',__('Yes',DYNAMIC_TO_TOP_DOMAIN),'yes',false,__('Show a text version instead of the arrow up icon.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_inset') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_inset() 
	{
		echo dynamic_to_top_do_checkbox('inset',__('Yes',DYNAMIC_TO_TOP_DOMAIN),'yes',true,__('Add CSS3 inset-highlight.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_shadow') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_shadow() 
	{
		echo dynamic_to_top_do_checkbox('shadow',__('Yes',DYNAMIC_TO_TOP_DOMAIN),'yes',true,__('Add CSS3 shadow.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_weight') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_bold() 
	{
		echo dynamic_to_top_do_checkbox('bold',__('Yes',DYNAMIC_TO_TOP_DOMAIN),'yes',true,__('Make the text bold.',DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('dynamic_to_top_field_text_shadow') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_field_text_shadow() 
	{
		echo dynamic_to_top_do_checkbox('text_shadow',__('Yes',DYNAMIC_TO_TOP_DOMAIN),'yes',true,__('Add a subtle text shadow.',DYNAMIC_TO_TOP_DOMAIN));
	}
}
/*
|--------------------------------------------------------------------------
| DYNAMIC TO TOP OPTION FIELDS HELPERS
|--------------------------------------------------------------------------
*/

if ( !function_exists('dynamic_to_top_do_checkbox') )
{
	
	/** 
	* Do Checkbox
	*
	* Generates a checkbox.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_do_checkbox($meta,$label="Yes",$value='yes',$checked=false,$desc="")
	{

		$options_db = get_option('dynamic_to_top');

		if (isset($options_db[$meta]) && $options_db[$meta] == $value) 
			$c = 'checked="checked"'; 
		else
			$c="";
			
		
	   	if ( $desc != "")
		$desc = '<div class="desc">'.$desc.'</div>';
		
		$sanitized_meta_title = str_replace('_','-',sanitize_title($meta));

		return '<input type="checkbox" name="dynamic_to_top['.$meta.']" value="'.$value.'" '.$c.' id="checkbox-'.$sanitized_meta_title.'" /> '.$label.$desc;	
	}
}

if ( !function_exists('dynamic_to_top_do_textfield') )
{
	
	/** 
	* Do Textfield
	*
	* Generates a Textfield.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_do_textfield($meta,$value="",$desc="",$class="")
	{

		$options_db = get_option('dynamic_to_top');

		if ( isset($options_db[$meta])) 
		$value = $options_db[$meta]; 
		
	   	if ( $desc != "")
		$desc = '<div class="desc">'.$desc.'</div>';
		
		if ( $class != "")
		$class = 'class="'.$class.'"';
		
		$sanitized_meta_title = str_replace('_','-',sanitize_title($meta));
		
		return '<input type="text" id="text-'.$sanitized_meta_title.'" name="dynamic_to_top['.$meta.']" '.$class.' value="'.$value.'" /> '.$desc;	
	}
}

if ( !function_exists('dynamic_to_top_do_select') )
{
	
	/** 
	* Do Select Box
	*
	* Generate a select box.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_do_select($meta,$options=array(),$value="",$desc="")
	{

		$options_out  = "";
		
		$options_db = get_option('dynamic_to_top');
		
		if ( isset($options_db[$meta]))
		$value = $options_db[$meta];
		
		$value = sanitize_title($value);

		foreach ($options as $option) 
		{
			$selected = "";
			
			$option_slug = sanitize_title($option);
			
			if ( $value == $option_slug )
			$selected = 'selected="selected"'; 
			
			$options_out .= '<option name="'.sanitize_title($option).'" '.$selected.' >'.$option.'</option>';
		}
		
	   	if ( $desc != "")
		$desc = '<div class="desc">'.$desc.'</div>';
		
		$sanitized_meta_title = str_replace('_','-',sanitize_title($meta));

	   return '<select name="dynamic_to_top['.$meta.']" id="select-'.$sanitized_meta_title.'"> '.$options_out.'</select>'.$desc;	
	}
}

if ( !function_exists('dynamic_to_top_do_textfield_color') )
{
	
	/** 
	* Do Textfield Color
	*
	* Generates a Textfield with Farbtastic.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_do_textfield_color($meta,$value="",$desc="",$class="")
	{

		$options_db = get_option('dynamic_to_top');

		if ( isset($options_db[$meta])) 
		$value = $options_db[$meta]; 
		
	   	if ( $desc != "")
		$desc = '<div class="desc">'.$desc.'</div>';
		
		if ( $class != "") 
		$class .= " ";
		
		$class = 'class="'.$class.'colorvalue"';
		
		$sanitized_meta_title = str_replace('_','-',sanitize_title($meta));

	   	$out ='<div id="farbtastic-picker-'.$sanitized_meta_title.'" class="dtt-farbtastic">';
		$out .= '</div><input type="text" name="dynamic_to_top['.$meta.']" id="farbtastic-'.$sanitized_meta_title.'" '.$class.' value="'.$value.'" />';
		$out .= '<a class="picker" href="#" data-closed="'.__('Close',DYNAMIC_TO_TOP_DOMAIN).'" data-open="'.__('Open',DYNAMIC_TO_TOP_DOMAIN).'">'.__('Open',DYNAMIC_TO_TOP_DOMAIN).'</a>'.$desc;
		
		return $out;
	}
}

if ( !function_exists('dynamic_to_top_do_slider') )
{
	
	/** 
	* Do Textfield Color
	*
	* Generates a Textfield with a slider.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function dynamic_to_top_do_slider($meta,$value="",$desc="",$class="")
	{

		$options_db = get_option('dynamic_to_top');

		if ( isset($options_db[$meta])) 
		$value = $options_db[$meta]; 
		
	   	if ( $desc != "")
		$desc = '<div class="desc">'.$desc.'</div>';
		
		if ( $class != "") 
		$class .= " ";
		
		$class = 'class="'.$class.'colorvalue"';
		
		$sanitized_meta_title = str_replace('_','-',sanitize_title($meta));

	   return '<div id="slider-picker-'.$sanitized_meta_title.'" class="dtt-slider"></div><input type="text" name="dynamic_to_top['.$meta.']" id="slider-'.$sanitized_meta_title.'" '.$class.' value="'.$value.'" />'.$desc;	
	}
}